Blender Git Commit Log

All Blender Git commits.

Page: 3940 / 8462

Revision c1dc078 by Mike Erwin (master)
April 7, 2017, 20:00 (GMT)
Gawain: remove GL enum from vertex format API

Callers now have to use Gawain's COMP enum to specify vertex attributes.

This makes the API more bullet-proof (at least less vulnerable) since GLenum covers waaay more than component types.

Also prepares us for Vulkan.
Revision 1ad5287 by Mike Erwin (master)
April 7, 2017, 19:51 (GMT)
use COMP instead of GL enum to construct vertex format

I converted all other files a day or two ago; this file was part of a recent merge.
Revision da24848 by Mike Erwin (master)
April 7, 2017, 19:10 (GMT)
OpenGL: remove UI_reinit_gl_state function

All line & point drawing is responsible for setting its own state (as of January 2016) making this redundant.
Revision 7a75581 by Mike Erwin (master)
April 7, 2017, 19:03 (GMT)
OpenGL: transition away from GL_QUADS

Single quads are drawn as a TRIANGLE_FAN, with 4 verts in the same order.

Multiple quads now use PRIM_QUADS_XXX and will need further work. Only 8 places still use this.

Part of T49043
Revision d6ae378 by Mike Erwin (master)
April 7, 2017, 18:21 (GMT)
Gawain: append XXX to PRIM_QUADS to make it scary

Quads are not part of modern GL or Vulkan, so we should avoid them. XXX makes coders think "hmm how could I draw this without using quads?"

Quads will be removed during the transition to core profile.

Part of T49043
Revision 23b10b5 by Mike Erwin (master)
April 7, 2017, 17:48 (GMT)
fix use of uninitialized variable

Bug crawled in via 2944438e9a276e48d7eabb5bb88ecec9b2f1e7dc as part of custom manipulators.
Revision 3f6d25f by Mike Erwin (master)
April 7, 2017, 17:28 (GMT)
shrink fixed-size internal GLSL string buffers

We concatenate #defines and #extensions into these, and can count the max string lengths needed. 256 is enough to hold today's strings; we can adjust later if needed.
Revision 1a156f7 by Mike Erwin (master)
April 7, 2017, 17:24 (GMT)
use best GPU matrix function for the job

Follow-up to 204e067111af9346fccea9981a0a7962ec8ef906 which coverted manipulators' legacy GL matrix calls to new ones.

part of T49450
Revision f0ce39a by Mike Erwin (master)
April 7, 2017, 16:51 (GMT)
OpenGL: support GLSL 3.3 core profile

When WITH_LEGACY_OPENGL = OFF.

This is our final target for Blender 2.8, all previous versions will be dropped in the future. GLSL 3.3 is richer so we don't require as many extensions.
April 7, 2017, 16:28 (GMT)
Cycles: Fix warning with MSVC
April 7, 2017, 16:28 (GMT)
Cycles: Fix compilation error with certain CUDA and host compiler configuration

This seems to happen on Windows only, happened to Thomas and Nathan already.

Similar patch Thomas was showing, but i do not see it committted. So comitting
now in order to get more developers and users happy.
April 7, 2017, 16:28 (GMT)
Tests: Compare vectors with epsilon

SOlves the test false-positively failing in 32 bit environment.
April 7, 2017, 16:26 (GMT)
[Cycles/msvc] Get cycles_kernel compile time under control.

Ever since we merged the extra texture types (half etc) and spit kernel the compile time for cycles_kernel has been going out of control.

It's currently sitting at a cool 1295.762 seconds with our standard compiler (2013/x64/release)

I'm not entirely sure why msvc gets upset with it, but the inlining of matrix near the bottom of the tri-cubic 3d interpolator is the source of the issue, this patch excludes it from being inlined.

This patch bring it back down to a manageable 186 seconds. (7x faster!!)

with the attached bzzt.blend that @sergey kindly provided i got the following results with builds with identical hashes

58:51.73 buildbot
58:04.23 Patched

it's really close, the slight speedup could be explained by the switch instead of having multiple if's (switches do generate more optimal code than a chain of if/else/if/else statements) but in all honesty it might just have been pure luck (dev box,very polluted, bad for benchmarks) regardless, this patch doesn't seem to slow down anything with my limited testing.

{F532336}

{F532337}

Reviewers: brecht, lukasstockner97, juicyfruit, dingto, sergey

Reviewed By: brecht, dingto, sergey

Subscribers: InsigMathK, sergey

Tags: #cycles

Differential Revision: https://developer.blender.org/D2595
April 7, 2017, 16:00 (GMT)
Workaround for weightpoint not working

Kudos to Germano Cavalcante for spotting the issue, the real fix is to pass SL to the function though
April 7, 2017, 15:57 (GMT)
Libmv: Correction to previous commit

We do need to make a copy of the values.
April 7, 2017, 15:54 (GMT)
Sync with blender2.8, cleanup, remove unintentionally committed files
April 7, 2017, 15:51 (GMT)
Simplified some test code in render_layer_common.py
April 7, 2017, 15:50 (GMT)
No more need to alter sys.path in each and every render_layer unit test.

I tried the clean way, by setting the PYTHONPATH environment variable for
CTest, using SET (CTEST_ENVIRONMENT blablab), but that didn't seem to
work.
April 7, 2017, 15:29 (GMT)
Tests: import blendfile without modifying sys.path
April 7, 2017, 15:28 (GMT)
Merge branch 'master' into blender2.8

# Conflicts:
# source/blender/alembic/intern/abc_exporter.h
# source/blender/alembic/intern/abc_util.cc
By: Miika HämäläinenLast update: Nov-07-2014 14:18MiikaHweb | 2003-2021